@@ -1319,13 +1319,16 @@ static gboolean
 dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
                                    GCancellable  *cancellable)
 {
-  GVariant *result;
+  GVariant *result = NULL;
   char *name;
+  char *name_owner = NULL;
   GVariant *value;
-  GVariantIter *iter;
+  GVariantIter *iter = NULL;
+  gboolean ret = FALSE;
 
+  name_owner = g_dbus_proxy_get_name_owner (proxy);
   result = g_dbus_connection_call_sync (g_dbus_proxy_get_connection (proxy),
-                                        g_dbus_proxy_get_name_owner (proxy),
+                                        name_owner,
                                         g_dbus_proxy_get_object_path (proxy),
                                         "org.freedesktop.DBus.Properties",
                                         "GetAll",
@@ -1336,7 +1339,7 @@ dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
                                         cancellable,
                                         NULL);
   if (result == NULL)
-    return FALSE;
+    goto out;
 
   g_variant_get (result, "(a{sv})", &iter);
   while (g_variant_iter_next (iter, "{sv}", &name, &value))
@@ -1346,8 +1349,14 @@ dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
       g_free (name);
       g_variant_unref (value);
     }
-  g_variant_iter_free (iter);
-  return TRUE;
+
+  ret = TRUE;
+
+ out:
+  g_clear_pointer (&iter, (GDestroyNotify) g_variant_iter_free);
+  g_clear_pointer (&result, (GDestroyNotify) g_variant_unref);
+  g_free (name_owner);
+  return ret;
 }
 
 static gboolean
